/*----------------------------------------------------------------
 * winmain.c -- entry point for Windows
 *----------------------------------------------------------------
 *  This is the outer startup/shutdown code for the Windows
 *  version.
 *
 *  This code initialises WinAllegro, then calls the shared game
 *  code, and finally shuts down WinAllegro.
 *
 *  A critical error handler is also defined here, which is
 *  callable from anywhere in the program.  It displays an error
 *  message and exits.  This is the Windows version, which uses
 *  `MessageBox' to display error messages.  This is only
 *  possible when WinAllegro has been shut down.
 */

#include <stdio.h>
#include <stdarg.h>

/*#define WIN32_LEAN_AND_MEAN
#define BITMAP WINDOWS_BITMAP
//#include <windows.h>
#undef BITMAP
#undef RGB
*/

#include <allegro.h>
#include "criterr.h"       /* prototype for `critical_error' */
#include "boot.h"          /* prototype for `boot' */

/* WinMain:
 *  This is the Windows entry point.  It must initialise WinAllegro and
 *  call the game's `boot' routine.  When that returns, it shuts down
 *  WinAllegro and exits.
 */
int main()
{
//	allegro_init();
	boot (0, NULL ); //WinAllegro_GetArgc(), WinAllegro_GetArgv());
//	allegro_exit();       /* just in case `boot' didn't do it */
	return 0;
}
END_OF_MAIN();

/* critical_error:
 *  This function is used to report critical errors (such as being
 *  unable to enter a graphics mode).  This is the Windows version,
 *  which uses MessageBox to display the message.  We need to shut
 *  down WinAllegro before this will work properly.
 */
void critical_error (const char *format, ...)
{
	va_list args;
	static char buffer[1024];

	va_start (args, format);
	vsprintf (buffer, format, args);
	va_end (args);

	allegro_exit();
	exit (-1);
}
